mtree

package
v0.3.19 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Package mtree implements the `img mtree` subcommand, which writes an mtree(8) specification describing the metadata of one or more layers.

Inputs are given by repeatable --tar, --cstream, and --mtree flags and are processed in the order they appear on the command line (they may be interleaved). A tar blob (--tar) may be gzip/zstd-compressed; a compact stream (--cstream) is reconstructed with zero-filled bodies and its content digests come from the CAS reference table / inlined bytes; an mtree spec (--mtree) is folded in with its keywords filtered to the requested field set and its paths re-normalized. The path layout, field set, and layer layout are controlled by --path-prefix, --options, and --layout.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MtreeProcess

func MtreeProcess(ctx context.Context, args []string)

Types

This section is empty.

Jump to